==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ActionDescriptorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ActionDescriptorBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorBuilder>{
  public ActionDescriptorBuilder() {
    this(false);
  }
  public ActionDescriptorBuilder(java.lang.Boolean validationEnabled) {
    this(new ActionDescriptor(), validationEnabled);
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ActionDescriptor(), validationEnabled);
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor instance) {
    this(fluent, instance, false);
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withPath(instance.getPath()); 
    fluent.withValue(instance.getValue()); 
    fluent.withXDescriptors(instance.getXDescriptors()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor instance) {
    this(instance,false);
  }
  public ActionDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ActionDescriptor build() {
    ActionDescriptor buildable = new ActionDescriptor(fluent.getDescription(),fluent.getDisplayName(),fluent.getPath(),fluent.getValue(),fluent.getXDescriptors());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ActionDescriptorBuilder that = (ActionDescriptorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.4.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ActionDescriptorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ActionDescriptorBuilder extends ActionDescriptorFluentImpl<ActionDescriptorBuilder> implements VisitableBuilder<ActionDescriptor,ActionDescriptorBuilder>{
  public ActionDescriptorBuilder() {
    this(false);
  }
  public ActionDescriptorBuilder(Boolean validationEnabled) {
    this(new ActionDescriptor(), validationEnabled);
  }
  public ActionDescriptorBuilder(ActionDescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public ActionDescriptorBuilder(ActionDescriptorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ActionDescriptor(), validationEnabled);
  }
  public ActionDescriptorBuilder(ActionDescriptorFluent<?> fluent,ActionDescriptor instance) {
    this(fluent, instance, false);
  }
  public ActionDescriptorBuilder(ActionDescriptorFluent<?> fluent,ActionDescriptor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withPath(instance.getPath()); 
    fluent.withValue(instance.getValue()); 
    fluent.withXDescriptors(instance.getXDescriptors()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ActionDescriptorBuilder(ActionDescriptor instance) {
    this(instance,false);
  }
  public ActionDescriptorBuilder(ActionDescriptor instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ActionDescriptorFluent<?> fluent;
  Boolean validationEnabled;
  public ActionDescriptor build() {
    ActionDescriptor buildable = new ActionDescriptor(fluent.getDescription(),fluent.getDisplayName(),fluent.getPath(),fluent.getValue(),fluent.getXDescriptors());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
